@@ -1,8 +1,8 @@
 from typing import Tuple
 
-from torch import Tensor, matmul, nn, reshape, transpose
+from torch import Tensor, matmul, nn, reshape, transpose, zeros
 
-from .padding import get_padding_same_conv2d
+from .paddings import get_padding_same_conv2d
 
 
 class Reshape(nn.Module):
@@ -30,7 +30,7 @@ class GANAttention2d(nn.Module):
     GAN related Attention Paper: https://arxiv.org/pdf/1805.08318.pdf
     """
 
-    def __init__(self, z: Tuple[int, int, int], channel_divisor: int, gamma: Tensor, gain: int = 1e-4):
+    def __init__(self, z: Tuple[int, int, int], channel_divisor: int, gain: int = 1e-4):
         """
         Init for GANGAttention2d
 
@@ -38,8 +38,6 @@ class GANAttention2d(nn.Module):
         :type tuple(int, int, int): input with format of tuple(channels, width, height)
         :param channel_divisor: divisor to calculate f_g_channel (f_g_channel=channels//channel_divisor)
         :type channel_divisor: int
-        :param gamma: hyperparameter, scalar and should be initialized as 0
-        :type gamma: Tensor
         :param gain: weight parameter for orthogonal initialization 
         :type gain: float
         """
@@ -55,7 +53,7 @@ class GANAttention2d(nn.Module):
         self.channels, self.height, self.width = z
 
         # Global value for all pixels, measures how important is the context for each of them.
-        self.gamma = gamma
+        self.gamma = nn.Parameter(zeros(1))
 
         self.f_g_channels = self.channels//channel_divisor
 
@@ -86,12 +84,12 @@ class GANAttention2d(nn.Module):
         h_flat = reshape(
             self.h(x), shape=[x.size(0), self.channels, self.height*self.width])
 
-        # TODO changed due to different handling between tf and pytorch logic
+        # TODO check, since logic changed due to different handling between tf and pytorch logic
         s = matmul(transpose(g_flat, dim0=1, dim1=2), f_flat)
 
         beta = nn.functional.softmax(s, dim=1)
 
-        # TODO changed due to different handling between tf and pytorch logic
+        # TODO check, since logic changed due to different handling between tf and pytorch logic
         o = matmul(h_flat, beta)
 
         o = reshape(o, shape=[x.size(0), self.channels,
